import axios from './axios.js';
const DISPATCH_HOST = '/ems-shared-dispatch-application';
const SUCCESS_CODE = 'S000A000';

// emsTable list
export const emsTableUrls = {
  shareCenterManage: `${DISPATCH_HOST}/share/centers/list`,
  dispatchDimensionManage: `${DISPATCH_HOST}/dimensions/list`,
  shareCenterConfig: `${DISPATCH_HOST}/share/centers/items`,
  priorityList: `${DISPATCH_HOST}/priority/list`,
  taskPoolList: `${DISPATCH_HOST}/business/scopes/list`,
  abnormalDispatchList: `${DISPATCH_HOST}/pretreatments/page`,
  QueryTaskPoolNotAssignGroup: `${DISPATCH_HOST}/accountPools/unspecified/list`,
  QueryTaskPoolNotAllotGroup: `${DISPATCH_HOST}/accountPools/unassigned/list`,
  QueryNoSubCenterList: `${DISPATCH_HOST}/accountPools/unspeciSubCentre/list`,
  QueryUnhandledList: `${DISPATCH_HOST}/accountPools/unhandled/list`,
  queryDuringWorkRange: '/ems-account-service/accountantMonthlyClosing/getConfigs',
  QuerySeparateWorkRange: '/ems-account-service/accountantAssign/getAccountantAssignConfigs',
  dispatchDimensionParent: `${DISPATCH_HOST}/dimensions/items/values/list`
};

// 导出
export const downloadUrls = {
  dispatchDimension: '/ems-shared-dispatch-application/dimensions/excel/export ',
  taskPoolWorkRange: '/ems-shared-dispatch-application/business/scopes/excel/export'
};

// 多语言
export const langUrls = {
  shareCenterUpdate: `${DISPATCH_HOST}/share/centers/lang`,
  shareCenterQuery: `${DISPATCH_HOST}/share/centers/lang`,
  dimensions: `${DISPATCH_HOST}/dimensions/lang`,
  dimensionsItem: `${DISPATCH_HOST}/dimensions/items/lang`,
  dimensionsItemValue: `${DISPATCH_HOST}/dimensions/items/values/lang`,
  accountantCalendarGet: `${DISPATCH_HOST}/accountantCalendar/new/language/get`,
  accountantCalendarUpdate: `${DISPATCH_HOST}/accountantCalendar/new/language/update`,
  priorityQuery: `${DISPATCH_HOST}/priority/lang`,
  priorityUpdate: `${DISPATCH_HOST}/priority/lang`,
  shareOrgQuery: `${DISPATCH_HOST}/shared/language/get`,
  shareOrgUpdate: `${DISPATCH_HOST}/shared/language/update`
};

// 获取用户相关的初始化数据
export const getSysNavInfo = (param = {}) => {
  return new Promise(resolve => {
    axios
      .post('/ems-base-application/mams/sys/nav/infoV2', param)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 当前登陆用户信息
export const findCurrentEmployee = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .get('/ems-base-application/tsUserOrg/findCurrentEmployee', param)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 会计
export const isAccountant = (empNo = '') => {
  return new Promise(resolve => {
    $axios
      .post(`/ems-shared-dispatch-application/shared/org/Userinfo/${empNo}`)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 切换语言
export const switchLang = param => {
  return new Promise((resolve, reject) => {
    axios
      .post('/ems-base-application/mams/sys/lang/switch', param)
      .then(response => {
        if (response.data.statusCode == '0') {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      });
  });
};

// 打开新页面需要的接口
export const queryProcessInfoByClaimNo = (param = {}) => {
  return new Promise(resolve => {
    axios
      .post(
        `/ems-utservice/claimProcessTaskMgr/myclaimhisbyclaimno/${param.claimNo}`,
        {}
      )
      .then(response => {
        const data = response.data;
        resolve(data);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 查询日历列表
export const findCalendars = `${DISPATCH_HOST}/accountantCalendar/new/pageInfo`;

export const GetValueSetByCode = param => {
  return new Promise((resolve, reject) => {
    axios
      .get(`/ems-base-application/mams/sys/valueset/item/list/${param.code}`)
      .then(response => {
        const data = response.data;
        if (data.statusCode === '0') {
          const result = [];
          for (const item of data.dataResult) {
            result.push({ label: item.vsiValue, value: item.vsiKey });
          }
          resolve(result);
        } else {
          reject(data.msg);
        }
      })
      .catch(err => reject(err));
  });
};

export const SaveDispatchDimension = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const DelDispatchDimension = param => {
  return new Promise((resolve, reject) => {
    axios
      .delete(`${DISPATCH_HOST}/dimensions`, {
        data: param
      })
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const GetDispatchDimensionItems = param => {
  return new Promise((resolve, reject) => {
    axios
      .get(`${DISPATCH_HOST}/dimensions/items`, {
        params: param
      })
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const SaveDispatchDimensionItems = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions/items`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const DelDispatchDimensionItems = param => {
  return new Promise((resolve, reject) => {
    axios
      .delete(`${DISPATCH_HOST}/dimensions/items/${param}`)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const GetDispatchDimensionItemsValue = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions/items/values/list`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const SaveDispatchDimensionItemsValue = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions/items/values`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const CheckDimensionDelete = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions/checkDelete`, param)
      .then(response => {
        if ([SUCCESS_CODE, 'E_FO0042'].includes(response.data.code)) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const DimensionEnabled = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/dimensions/enabled`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const TaskMonitorGetShareCenter = param => {
  return new Promise((resolve, reject) => {
    axios
      .get(`${DISPATCH_HOST}/share/centers/queryByOwner`)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
export const GetShareCenter = param => {
  return new Promise((resolve, reject) => {
    axios
      .get(`${DISPATCH_HOST}/share/centers/queryByUserCode`)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 获取分中心信息
export const GetSubCenter = param => {
  return new Promise((resolve, reject) => {
    axios
      .get(`${DISPATCH_HOST}/shared/org/subcenters?sharedCenterCode=${param}`)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

// 日历设置 头保存
export const accountantCalendarEdit = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/accountantCalendar/new/edit`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历 状态变更
export const changeAccountantCalendarStatus = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/accountantCalendar/new/changeStatus`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历 删除前查询是否引用
export const checkCalendarCanBeDelete = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/accountantCalendar/new/checkCanBeDelete`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历 查询
export const QueryWorkCalendarInfo = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(
        `${DISPATCH_HOST}/accountantCalendar/new/findAllAccountantCalendarByCalendarCode`,
        params
      )
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历 保存时间
export const SetWorkTime = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(
        `${DISPATCH_HOST}/accountantCalendar/new/setAccountantCalendarWorkTime`,
        params
      )
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历 工作日/非
export const SetIsOrNoWorkDay = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(
        `${DISPATCH_HOST}/accountantCalendar/setAccountantCalendarWorkFlag`,
        params
      )
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心配置 -- 新增/编辑
export const shareCenterAdd = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}/share/centers`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 共享中心配置 -- 详情
export const shareCenterDetail = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .get(`${DISPATCH_HOST}/share/centers/${params.shareCenterCode}`)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心配置 -- 删除检测
export const shareCenterCheck = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/share/centers/checkQuoted`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心配置 -- 删除
export const shareCenterDelete = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .delete(`${DISPATCH_HOST}/share/centers`, { data: params })
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心配置 -- 检测 启用禁用
export const checkLockToggleLock = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/share/centers/checkLock`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心配置 -- 启用禁用
export const shareCenterToggleLock = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/share/centers/${params.status}`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 日历设置 复制
export const accountantCalendarCopy = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/accountantCalendar/new/copy`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心详情配置 -- 详情
export const shareCenterConfigDetail = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .get(`${DISPATCH_HOST}/share/centers/items/${params.shareCenterCode}`)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心详情配置 -- 编辑
export const shareCenterConfigEdit = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .put(`${DISPATCH_HOST}/share/centers/items`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享中心详情配置 -- 派单维度列表
export const dimensionsList = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}/dimensions/list`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 共享中心详情配置 -- 工作日历列表
export const workDateList = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/accountantCalendar/new/pageInfo`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 优先级 新增编辑
export const priorityEdit = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}/priority`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 优先级 通过维度查询规则明细表格列
export const getDimensionsItems = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .get(`${DISPATCH_HOST}/dimensions/items/${params.code}`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 优先级 编辑 查询明细
export const getPriorityItems = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/priority/item/list`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 任务池设置 -- 删除
export const taskPoolDelete = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .delete(`${DISPATCH_HOST}/business/scopes`, { data: params })
      .then(response => {
        resolve(response.data);
      });
  });
};
// 任务池设置 ---详情
export const taskPoolDetail = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .get(`${DISPATCH_HOST}/business/scopes/${params.id}`)
      .then(response => {
        resolve(response.data);
      });
  });
};
// 任务池设置 ---新增/编辑
export const taskPoolAddOrEdit = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}//business/scopes`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 任务池设置 -- 启用禁用
export const taskPoolToggleLock = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/business/scopes/${params.status}`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 优先级 明细 删除
export const delPriorityItem = (params = []) => {
  return new Promise(resolve => {
    $axios
      .delete(`${DISPATCH_HOST}/priority/item`, { data: params })
      .then(response => {
        resolve(response.data);
      });
  });
};

// 查询 共享组织
export const getSharedOrgTree = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}/shared/org/tree`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 优先级 启用
export const priorityEnabled = (params = {}) => {
  return new Promise(resolve => {
    $axios.post(`${DISPATCH_HOST}/priority/enabled`, params).then(response => {
      resolve(response.data);
    });
  });
};

// 优先级 删除
export const delPriority = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .delete(`${DISPATCH_HOST}/priority`, { data: params })
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享组织管理 -- 共享组织详情查看
export const QueryShareOrgInfo = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/shared/org/info`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
export const QueryShareOrgInfoByCondition = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/shared/org/infoByList`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 共享组织管理 -- 共享组织详情保存
export const SaveShareOrgInfo = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/shared/org/edit`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

// 共享组织管理 -- 删除节点
export const DelShareOrgNode = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/shared/org/tree/deleteNode`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};

export const QueryShareOrgTree = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/shared/org/tree`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 查询第一个XX单
export const QueryAccountPoolSheetCount = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/accountPools/all/count`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 查询第二个XX单
export const QuerySecondNumCount = param => {
  return new Promise((resolve, reject) => {
    axios
      .post(`${DISPATCH_HOST}/accountPools/two/count`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 异常派单详情
export const AbnormalDispatchDetail = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .get(`${DISPATCH_HOST}/pretreatments/detail?id=${params.id}`)
      .then(response => {
        resolve(response.data);
      });
  });
};
export const QueryUnsepcifyNum = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/accountPools/unspeciSubCentre/count`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 获取审批环节字符串
export const GetApprovalDisplayData = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/accountPools/getGroupTypes`, param)
      .then(response => {
        if (response.data.code === SUCCESS_CODE) {
          resolve(response.data.data);
        } else {
          reject(response.data.msg);
        }
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 分配到小组
export const assignToGroup = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/accountPools/unspecified/manualProcess`, param)
      .then(response => {
        resolve(response);
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 分配到个人
export const assignToPerson = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/accountPools/unassigned/manualProcess`, param)
      .then(response => {
        console.log('response', response);
        resolve(response);
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 重新分配到个人
export const assignToPersonAgain = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/accountPools/unallocated/manualProcess`, param)
      .then(response => {
        resolve(response);
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 手工指定分中心
export const assignToSubCenter = param => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/centerPools/unspecified/manualProcess`, param)
      .then(response => {
        resolve(response);
      })
      .catch(error => reject(error.response.data.message));
  });
};
// 查询组员
export const QueryAllAccountingGroupMember = param => {
  return new Promise((resolve, reject) => {
    $axios
      .get(
        `${DISPATCH_HOST}/shared/org/groups/users?groupCode=${param.groupCode}`
      )
      .then(response => {
        console.log('response', response);
        resolve(response);
      })
      .catch(error => reject(error.response.data.message));
  });
};

// 会计月结期间设置 -- 删除会计月结期间列表信息
export const deleteDuringWorkRange = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .post('/ems-account-service/accountantMonthlyClosing/deleteConfig', param)
      .then(response => {
        resolve(response);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 会计月结期间设置 -- 创建会计月结期间列表信息
export const createDuringWorkRange = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .post('/ems-account-service/accountantMonthlyClosing/createConfig', param)
      .then(response => {
        resolve(response);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 会计月结期间设置 -- 更新会计月结期间列表信息
export const updateDuringWorkRange = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .post('/ems-account-service/accountantMonthlyClosing/updateConfig', param)
      .then(response => {
        resolve(response);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 创建会计分单任务列表
export const CreateSeparateWorkRange = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .post(
        '/ems-account-service/accountantAssign/createAccountantAssignConfigs',
        param
      )
      .then(response => {
        resolve(response);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 更新会计分单任务列表
export const UpdateSeparateWorkRange = (param = {}) => {
  return new Promise(resolve => {
    $axios
      .post(
        '/ems-account-service/accountantAssign/updateAccountantAssignConfig',
        param
      )
      .then(response => {
        resolve(response);
      })
      .catch(error => {
        const responseData = {
          dataResult: [],
          extra: '',
          msg: error.response.data.message || '服务异常，请联系管理员',
          statusCode: '-1'
        };
        resolve(responseData);
      });
  });
};

// 共享组织管理 -- 编辑保存前check
export const orgEditCheck = (params = {}) => {
  return new Promise(resolve => {
    $axios
      .post(`${DISPATCH_HOST}/shared/org/edit/check`, params)
      .then(response => {
        resolve(response.data);
      });
  });
};

// 共享组织管理 -- 删除前check
export const orgDeleteCheck = (params = {}) => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/shared/org/edit/checkDelte`, params)
      .then(response => {
        resolve(response.data);
      }).catch(error => reject(error.response.data.message));
  });
};

// 派单维度设置 -- 获取维度值集详情
export const getDimensionsDetailById = (id = '') => {
  return new Promise((resolve, reject) => {
    $axios
      .get(`${DISPATCH_HOST}/dimensions/items/values/${id}`)
      .then(response => {
        resolve(response.data);
      }).catch(error => reject(error.response.data.message));
  });
};

// 派单维度设置 -- 删除维度值集
export const deleteDimensionsDetailById = (id = '') => {
  return new Promise((resolve, reject) => {
    $axios
      .delete(`${DISPATCH_HOST}/dimensions/items/values?id=${id}`)
      .then(response => {
        resolve(response.data);
      }).catch(error => reject(error.response.data.message));
  });
};

// 派单维度设置 -- 删除维度值集前check
export const deleteDimensionsCheck = (id = '') => {
  return new Promise((resolve, reject) => {
    $axios
      .delete(`${DISPATCH_HOST}/dimensions/items/values/precheck?id=${id}`)
      .then(response => {
        resolve(response.data);
      }).catch(error => reject(error.response.data.message));
  });
};

// 异常派单 -- 手工处理
export const pretreatmentsManual = (param = {}) => {
  return new Promise((resolve, reject) => {
    $axios
      .post(`${DISPATCH_HOST}/pretreatments/manual`, param)
      .then(response => {
        resolve(response.data);
      }).catch(error => reject(error.response.data.message));
  });
};
