import Vue from 'vue';
import App from './App.vue';
import iView from 'view-design';
import VueRouter from 'vue-router';
import VueI18n from 'vue-i18n';
import LocalMixin from './mixin/index.js';
import './assets/css/common.css';
import 'ems-components-new/src/static/css/global.less';
import 'ems-components-new/src/assets/iconfont/iconfont.css';
import 'view-design/dist/styles/iview.css';
import './static/css/app.less';
import './static/css/index.less';
import 'core-js/stable';
import 'regenerator-runtime/runtime';
import store from './vuex';
import config from '../config.js';
import axios from './api/axios.js';
import { routers, flatRoutes } from './router';
import {
  componentsInstall,
  componentsZh,
  componentsTw,
  componentsEn
} from 'ems-components-new';
import iviewEn from 'view-design/dist/locale/en-US';
import iviewZh from 'view-design/dist/locale/zh-CN';
import iviewTw from 'view-design/dist/locale/zh-TW';
import {
  commonZh,
  commonEn,
  commonTw
} from 'ems-common-lang';

Vue.use(VueI18n);
Vue.use(iView, {
  i18n: function(path, options) {
    const value = i18n.t(path, options);
    if (value !== null && value !== undefined) {
      return value;
    }
    return '';
  }
});
Vue.use(VueRouter);
Vue.use(componentsInstall);
Vue.mixin(LocalMixin);

// 必须要加这个  不然多国语言切换不出效果
Vue.locale = () => { };

Vue.prototype.$config = config[process.env.VUE_APP_ENV];
window.$Message = Vue.prototype.$Message;
window.$axios = Vue.prototype.$axios = axios;

const router = new VueRouter({
  routes: routers
});

router.beforeEach((to, from, next) => {
  if (!to.path || !flatRoutes.filter(item => item.fullPath == to.path).length) {
    return iView.Message.error('未找到此页面');
  } else {
    iView.LoadingBar.start();
    store.commit('main/setCurrentPageName', to.name);
    next();
    router.app.$emit('RouterChangeBefore');
  }
});

router.afterEach(to => {
  if (to && to.meta && to.meta.title) {
    document.title = to.meta.title[1];
  }
  iView.LoadingBar.finish();
});

if (!localStorage.getItem('lang')) {
  localStorage.setItem('lang', 'zh-CN');
}

const i18n = new VueI18n({
  locale: window.localStorage.getItem('lang') || 'zh-CN',
  messages: {
    'zh-CN': Object.assign(iviewZh, commonZh, componentsZh, require('./lang/zh-CN.json')),
    'en-US': Object.assign(iviewEn, commonEn, componentsEn, require('./lang/en-US.json')),
    'zh-TW': Object.assign(iviewTw, commonTw, componentsTw, require('./lang/zh-TW.json'))
  }
});

window.emsConfig = {
  i18n,
  store
};

window.$app = new Vue({
  el: '#app',
  router,
  store,
  i18n,
  created() {
    if (sessionStorage.crctoken) {
      $axios.defaults.headers.crctoken = sessionStorage.crctoken;
    } else {
      this.$router.push({ path: 'login' });
    }

    this.setMessage();
  },
  methods: {
    setMessage() {
      this.$Message.config({
        duration: 6
      });
      window.$Message = this.$Message;
    }
  },
  render: h => h(App)
});

window.$config = Vue.prototype.$config;
window.$store = store;

// 开发环境配置 ------------start
if (process.env.NODE_ENV === 'development') {
  const consoleError = window.console.error;
  window.console.error = function(msg) {
    try {
      if (msg && msg.indexOf('[Vue warn]: Invalid prop: type check failed for prop "model". Expected Object, got Array') > -1) {
        return;
      }
    } catch (err) {
    }
    consoleError(msg);
  };

  // console.log('当前运行环境：', process.env.VUE_APP_ENV);
}
// 开发环境配置 ------------end
