import Router from 'vue-router';
const originalPush = Router.prototype.push;
Router.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err);
};

const flatRoutes = [];

// 对外暴露的router 不能用变量作为路径的
const accountingRouters = [
  {
    path: 'accounting/work-calendar-settings',
    name: 'work-calendar-settings',
    component: () => import('./views/accounting/workCalendarSettings/WorkCalendarSettings.vue'),
    meta: {
      title: ['共享派单', '工作日历设置']
    }
  },
  {
    path: 'accounting/share-center-manage',
    name: 'share-center-manage',
    component: () => import('./views/accounting/shareCenterManage/Index.vue'),
    meta: {
      title: ['共享派单', '共享中心设置']
    }
  },
  {
    path: 'accounting/share-org-manage',
    name: 'share-org-manage',
    component: () => import('./views/accounting/shareOrgManage/ShareOrgManage.vue'),
    meta: {
      title: ['共享派单', '共享组织设置']
    }
  },
  {
    path: 'accounting/dispatch-dimension-manage',
    name: 'dispatch-dimension-manage',
    component: () => import('./views/accounting/dispatchDimensionManage/DispatchDimensionManage.vue'),
    meta: {
      title: ['共享派单', '派单维度设置']
    }
  },
  {
    path: 'accounting/share-center-config',
    name: 'share-center-config',
    component: () => import('./views/accounting/shareCenterConfig/Index.vue'),
    meta: {
      title: ['共享派单', '共享中心详情设置']
    }
  },
  {
    path: 'accounting/priority-settings',
    name: 'priority-settings',
    component: () => import('./views/accounting/prioritySettings/PrioritySettings.vue'),
    meta: {
      title: ['共享派单', '优先级设置']
    }
  },
  {
    path: 'accounting/task-pool-work-range',
    name: 'task-pool-work-range',
    component: () => import('./views/accounting/taskPoolWorkRange/Index.vue'),
    meta: {
      title: ['共享派单', '任务池业务范围设置']
    }
  },
  {
    path: 'accounting/accounting-post-time-setting',
    name: 'accounting-post-time-setting',
    component: () => import('./views/accounting/accountingPostTimeSetting/Index.vue'),
    meta: {
      title: ['共享派单', '会计岗位时间设置']
    }
  },
  {
    path: 'accounting/abnormal-dispatch',
    name: 'abnormal-dispatch',
    component: () => import('./views/accounting/abnormalDispatch/Index.vue'),
    meta: {
      title: ['共享派单', '异常派单']
    }
  },
  {
    path: 'share-center-task-pool-monitor',
    name: 'share-center-task-pool-monitor',
    component: () => import('./views/accounting/taskPoolMonitor/Index.vue'),
    meta: {
      title: ['共享派单', '任务池监控']
    }
  },
  // 老页面迁移
  {
    path: 'accounting-group',
    name: 'accounting-group',
    component: () => import('./views/accounting/accountingGroup/Index.vue'),
    meta: {
      title: ['共享派单', '会计分组设置']
    }
  },
  {
    path: 'group-work-range',
    name: 'group-work-range',
    component: () => import('./views/accounting/groupWorkRange/Index.vue'),
    meta: {
      title: ['共享派单', '小组工作范围']
    }
  },
  {
    path: 'accounting-work-calendar',
    name: 'accounting-work-calendar',
    component: () => import('./views/accounting/accountingWorkCalendar/Index.vue'),
    meta: {
      title: ['共享派单', '会计工作日历']
    }
  },
  {
    path: 'accounting-not-on-duty',
    name: 'accounting-not-on-duty',
    component: () => import('./views/accounting/accountingNotOnDuty/Index.vue'),
    meta: {
      title: ['共享派单', '会计不在岗设置']
    }
  },
  {
    path: 'accounting-on-duty',
    name: 'accounting-on-duty',
    component: () => import('./views/accounting/accountingOnDuty/Index.vue'),
    meta: {
      title: ['共享派单', '会计在岗设置']
    }
  },
  {
    path: 'task-pool-monitor',
    name: 'task-pool-monitor',
    component: () => import('./views/accounting/accountingTaskPoolMonitor/Index.vue'),
    meta: {
      title: ['共享派单', '任务池监控']
    }
  },
  {
    path: 'create-invoice-monitor',
    name: 'create-invoice-monitor',
    component: () => import('./views/accounting/createInvoiceMonitor/Index.vue'),
    meta: {
      title: ['共享派单', '生成发票监控']
    }
  },
  {
    path: 'query-create-invoice-monitor',
    name: 'query-create-invoice-monitor',
    component: () => import('./views/accounting/queryCreateInvoiceMonitor/Index.vue'),
    meta: {
      title: ['共享派单', '查询生成发票监控']
    }
  },
  {
    path: 'group-work-range-query-chart',
    name: 'group-work-range-query-chart',
    component: () => import('./views/accounting/groupWorkRangeQuery/Index.vue'),
    meta: {
      title: ['共享派单', '小组人员工作范围查询报表']
    }
  },
  {
    path: 'accounting-separate-duty',
    name: 'accounting-separate-duty',
    component: () => import('./views/accounting/accountingSeparateDuty/index.vue'),
    meta: {
      title: ['共享派单', '会计分单设置']
    }
  },
  {
    path: 'accounting-during-duty',
    name: 'accounting-during-duty',
    component: () => import('./views/accounting/accountingDuringDuty/index.vue'),
    meta: {
      title: ['共享派单', '会计月结期间设置']
    }
  },
  {
    path: 'sap-interface-monitor',
    name: 'sap-interface-monitor',
    component: () => import('./views/accounting/createSapMonitor/Index.vue'),
    meta: {
      title: ['共享派单', 'SAP接口监控']
    }
  },
  {
    path: 'sap-interface-show-detail',
    name: 'sap-interface-show-detail',
    title: 'SAP接口详情数据',
    component: resolve => {
      require(['./views/accounting/createSapMonitor/components/showJsonData.vue'], resolve);
    },
    meta: {
      title: ['共享派单', 'SAP接口详情数据', 'QQ']
    }
  }
];

const routers = [{
  path: '/',
  redirect: {
    name: 'home'
  }
},
{
  path: '/',
  component: () => import('./components/main/Main.vue'),
  children: [
    ...accountingRouters,
    {
      path: 'home',
      name: 'home',
      component: () => import('./views/home/Home.vue'),
      meta: {
        title: ['首页', '首页']
      }
    }
  ]
},
{
  path: '/login',
  name: 'login',
  component: () => import('./views/login/Login.vue'),
  meta: {
    title: ['登录', '登录'],
    auth: false
  }
}
];

function eachItem(items, path) {
  items.map((item, index) => {
    if (item.children && item.children.length) {
      eachItem(item.children, item.path);
    } else {
      if (item.meta) {
        item.meta.title && (items[index].title = item.meta.title[1]);
      } else {
        item.meta = {};
      }

      item.fullPath = `${path}${item.path}`;
      flatRoutes.push(item);
    }
  });
}
eachItem(routers, '');

console.log(flatRoutes);
accountingRouters.forEach(item => item.meta.csswrap = 'ems-accounting-web');

export {
  accountingRouters,
  flatRoutes,
  routers
};
