import { util as utilCn } from 'ems-components-new';
import qs from 'qs';
import accounting from 'accounting';
import { queryProcessInfoByClaimNo } from '@accountingSrc/api/server.js';
import extend from 'extend';

const util = { ...utilCn };

util.simDeepCopy = function(obj) {
  return JSON.parse(JSON.stringify(obj));
};

util.randomId = function() {
  return new Date().getTime() + '' + parseInt(Math.random() * 10000);
};

// 给对象加上randomId,字段默认为rid，改方法直接修改对象
util.addRandomId = function(items = {}, rid = 'rid') {
  if (!items.length) {
    // 如果传入的是单个对象
    items[rid] = util.randomId();
  } else {
    // 如果是数组对象
    items.map(item => item[rid] = util.randomId());
  }
  return items;
};

util.getUrlParams = function(url) {
  const uri = url || location.href;
  const searchStr = uri.split('?')[1];
  const result = {};
  if (!searchStr) {
    return result;
  } else {
    return qs.parse(searchStr);
  }
};

util.isString = function(str) {
  return Object.prototype.toString.call(str) === '[object, String]';
};

util.isObject = function(obj) {
  return Object.prototype.toString.call(obj) === '[object, Object]';
};

util.isArray = function(obj) {
  return Object.prototype.toString.call(obj) === '[object, Array]';
};

// 银行账号加 ***
util.formatAccountNo = function(accountNo) {
  if (!accountNo) {
    return;
  }
  return String(accountNo).replace(/^(.{3}).+(.{4})$/g, '$1****$2');
};

// 日期转换为毫秒
util.formatDateToMilSec = function(date) {
  if (!date) {
    return;
  }
  return new Date(date).getTime();
};

// 日期转换为秒
util.formatDateToSec = function(date) {
  return parseInt(util.formatDateToMilSec(date) / 1000);
};

// 格式化金额
util.formatMoney = function(val) {
  return accounting.formatMoney(val, '');
};

// 数字四舍五入，保留X位小数
util.toFixed = function(val, p = 2) {
  return accounting.toFixed(val, p);
};

// 四舍五入保留2位小数,并格式化金额
util.toMoney = function(val, p = 2) {
  return util.formatMoney(util.toFixed(val, p));
};

// 打开新页面
util.openLinkPage = (url) => {
  const link = document.createElement('a');
  link.style.display = 'none';
  link.href = url;
  link.setAttribute('target', '_blank');
  document.body.appendChild(link);
  link.click();
  document.body.removeChild(link);
};

// 打开新页面的方法
util.openTask = function(data) {
  queryProcessInfoByClaimNo({
    claimNo: data.relClaimNo
  })
    .then(response => {
      const dataResult = response.list[0];
      dataResult.actionType = 'done';
      if (data.isSubmit) {
        dataResult.source = 'other';
        dataResult.isSubmit = data.isSubmit;
      }
      util.openTaskFromBillOfAccount(dataResult);
    })
    .catch(error => { });
};

// 打开新页面用到的方法
util.openTaskFromBillOfAccount = function(data) {
  let singlePage = 'NO';
  let pageName = data.tpcode || '';
  const origin = util.getOrigin();
  // let origin = '';
  // if(location.origin != location.href.split('/#')[0]){
  //   origin = location.href.split('/#')[0];
  // }else{
  //   origin = location.origin;
  // }
  let url = '';
  let startUserCode = '';
  const currentNodeName = data.currentTaskName;
  const taskDefinitionKey = data.actID;
  let currentTaskId = '';

  // 获取跳转URL
  url = data.taskLocalVariables[0].url;
  if (url) {
    const tr = url.split('?')[0];
    const tp = 'create-payment-apply';
    if (!tr) {
      url = tp + url;
    }
    url = origin + '/' + url;
  } else {
    $app.$Message.error('该条数据无跳转的URL参数');
    return;
  }
  startUserCode = data.processVariables[0].procStartUserLdapId;

  // 获取当前节点taskId
  currentTaskId = data.currentTaskID;
  singlePage = 'YES';

  // ap
  if (pageName == 'payment-plan') {
    pageName = 'create-payment-apply';
  }
  // gl
  if (pageName == 'payment-plan-gl') {
    pageName = 'create-payment-apply';
  }
  // 跳转表单平台的
  if ($config.formPlatformUrls[pageName]) {
    url = $config.formPlatformUrls[pageName] + '?' + url.split('?')[1];
  }

  // || $store.state.reimburseComment.vm.loginInfo.userCode
  let targetUrl = `${url}&singlePage=${singlePage}&pageName=${pageName}&claimId=${data.claimId || data.processVariables[0].formInstId}&claimNo=${data.claimNo}&categoryName=${data.categoryName}&taskNodeType=${data.taskNodeType}&catalogyCode=${data.catalogyCode}&currentTaskId=${currentTaskId}&taskDefinitionKey=${taskDefinitionKey}&currentNodeName=${currentNodeName}&userCode=${
    $store.state.LoginUserInfo.userCode || this.getUrlParams().userCode || ''}&startUserCode=${startUserCode}&actionType=${data.actionType}&fromPendingRead=${data.fromPendingRead}&fromPendingFeedBack=${data.fromPendingFeedBack}`;
  /*  if (data.actID && targetUrl.indexOf("&actId=") > -1) {
        var regExp=/\actId=.*?\&/;
        targetUrl = targetUrl.replace(regExp,data.actID)
    } */
  if (data.actID && targetUrl.indexOf('&actId=') < 0) {
    targetUrl = targetUrl +
      `&actId=${data.actID}`;
  }
  // 增加取categoryCode  差旅费需要
  if (data.catalogyCode && targetUrl.indexOf('categoryCode') < 0) {
    targetUrl = targetUrl +
      `&categoryCode=${data.catalogyCode}`;
  }
  if (data.openMode && targetUrl.indexOf('&openMode=') < 0) {
    targetUrl = targetUrl +
      `&openMode=${data.openMode}`;
  }
  if (data.fromPendingFeedBack == 'Y' || data.fromAlreadyFeedBack == 'Y') {
    targetUrl = targetUrl +
      `&feedBackCreateUserCode=${data.feedBackCreateUserCode}&feedBackCreateUserName=${data.feedBackCreateUserName}&feedBackId=${data.id}`;
  }

  if (data.fromPendingRead == 'Y' || data.fromAlreadyRead == 'Y') {
    targetUrl = targetUrl +
      `&readId=${data.id}`;
  }

  if (data.source) {
    targetUrl = targetUrl +
      `&source=${data.source}`;
  }
  if (pageName = 'create-payment-apply') {
    targetUrl = targetUrl +
      '&showPayment=true';
  }
  targetUrl = targetUrl + `&crctoken=${sessionStorage.crctoken}`;
  if (data.isSubmit) {
    window.win_num = window.win_num + 1;
    window.win_Array[window.win_num] = window.location.replace(targetUrl);
    window.location.reload();
  } else {
    window.win_num = window.win_num + 1;
    window.win_Array[window.win_num] = window.open(targetUrl);
  }
};

// 也是打开新页面要用到的方法
util.getOrigin = function() {
  let origin = '';
  if (location.origin != location.href.split('/#')[0]) {
    origin = location.href.split('/#')[0];
  } else {
    origin = location.origin;
  }
  return origin;
};

// 打开页面专属获取地址栏参数
util.openTaskParams = function(url) {
  const uri = url || location.href;
  if (uri.indexOf('?') > 0) {
    var params = uri.split('?')[1].split('&');
    var obj = {};
    params.map(v => obj[v.split('=')[0]] = v.split('=')[1]);
    return obj;
  } else {
    return {};
  }
};

// 计算字符数  中2英1数1
util.getByteLen = function(val) {
  var len = 0;
  for (var i = 0; i < val.length; i++) {
    var a = val.charAt(i);
    if (a.match(/[^\x00-\xff]/ig) != null) {
      // 业务需求不再区分汉字  所以改成1
      len += 1;
    } else {
      len += 1;
    }
  }
  return len;
};

// 关闭当前页面用到的方法
util.closeWebPage = function(val) {
  if (navigator.userAgent.indexOf('MSIE') > 0) {
    if (navigator.userAgent.indexOf('MSIE 6.0') > 0) {
      window.opener = null;
      window.close();
    } else {
      window.open('', '_top');
      window.top.close();
    }
  } else if (navigator.userAgent.indexOf('Firefox') > 0) {
    window.open('about:blank', '_self').close();
  } else {
    window.open('about:blank', '_self').close();
  }
};

// 打印需要用到的
util.printUrl = function(url) {
  const uri = url || location.href;
  if (uri.indexOf('?') > 0) {
    var params = uri.split('?')[1].split('&');
    var obj = {};
    params.map(v => obj[v.split('=')[0]] = v.split('=')[1]);
    return obj;
  } else {
    return {};
  }
};

/**
 * 文件下载通用方法
 *
 * 组件内使用方法: util.downloadFile.call(this, param)
 * param = {url: ''} url下载地址必填
 */
util.downloadFile = function(param = {}) {
  if (!param.url) {
    return console.error('url地址必须');
  }
  return new Promise((resolve) => {
    this.$Spin.show({
      render: (h) => {
        return h('div', [
          h('Icon', {
            class: 'demo-spin-icon-load',
            props: {
              type: 'ios-loading',
              size: 18
            }
          }),
          h('div', '正在努力下载附件，请稍候...')
        ]);
      }
    });
    $axios({
      method: param.method || 'get', // 方法
      url: `${param.url}`, // 地址
      responseType: 'blob',
      headers: {
        crctoken: sessionStorage.crctoken
      },
      data: param.data || {}
    }).then(response => {
      if (!response.data) {
        return;
      }
      if (!response.headers || !response.headers['content-disposition']) {
        throw Error('下载出错！');
      }
      const url = window.URL.createObjectURL(new Blob([response.data]));
      const _fileName = response.headers['content-disposition'].split('=');
      const fileName = param.name || (!!_fileName && _fileName.length > 1 ? _fileName[1] : 'file');
      // 兼容IE10+、edge
      if (window.URL.createObjectURL(new Blob()).indexOf(location.host) < 0) {
        if (window.navigator.msSaveOrOpenBlob) { // IE10+方法
          const blobObject = new Blob([response.data], {
            type: 'text/html'
          });
          window.navigator.msSaveOrOpenBlob(blobObject, decodeURI(fileName));
        }
        // 兼容chrome、fireFox
      } else {
        const link = document.createElement('a');
        link.style.display = 'none';
        link.href = url;
        link.setAttribute('download', decodeURI(fileName));
        document.body.appendChild(link);
        link.click();
      };
      this.$Spin.hide();
      resolve({
        msg: '导出成功'
      });
    }).catch(err => {
      this.$Message.error('下载失败！');
      this.$Spin.hide();
    });
  });
};

// 打开菜单页面
util.openTagPage = function(vm, active, params) {
  const tagsList = vm.$store.state.main.tagsList;
  const pageOpenedList = vm.$store.state.main.pageOpenedList;
  const openedPageLen = pageOpenedList.length;
  let i = 0;
  let tagHasOpened = false;
  while (i < openedPageLen) {
    if (pageOpenedList[i] && active === pageOpenedList[i].name) {
      vm.$store.commit('main/moveToSecond', i);
      tagHasOpened = true;
      break;
    }
    i++;
  }
  if (!tagHasOpened) {
    let tag = tagsList.filter(titem => {
      if (titem.children && titem.nest != 'YES') {
        return active === titem.children[0].name;
      } else {
        return active === titem.name;
      }
    });
    tag = tag[0];
    if (!tag) {
      $Message.warning({
        content: '未配置此路由'
      });
      return '0';
    };
    tag = tag.children ? tag.children[0] : tag;

    vm.$store.commit('main/increateTag', tag);
  }
  vm.$store.commit('main/setCurrentPageName', active);
  vm.$router.push({
    name: active,
    params: params
  });
};

// 打开报账单页面的方法
util.startProcess = function(obj) {
  let fullTpCode = obj.tpCode;
  const categoryCode = obj.categoryCode;
  const startProcess = function() {
    let tpCode = fullTpCode.split('?')[0];
    let tpCodeParams = {};
    if (fullTpCode.split('?')[1]) {
      tpCodeParams = qs.parse(fullTpCode.split('?')[1]);
    }

    // 处理从草稿、待办、已办过来的付款申请的大类模板
    if (tpCodeParams.backUrl && !!obj.source) {
      tpCode = tpCodeParams.backUrl;
    }

    const params = Object.assign({}, obj, {
      actionType: obj.actionType || 'start',
      categoryName: obj.categoryName,
      categoryCode: obj.categoryCode,
      ...tpCodeParams,
      singlePage: 'YES'
    });
    let origin = '';
    if (location.origin != location.href.split('/#')[0]) {
      origin = location.href.split('/#')[0];
    } else {
      origin = location.origin;
    }

    if (params.singlePage == 'YES') {
      $axios.get(`ems-base-application/templateconfig/bycode/${tpCode}`).then(res => {
        console.log('tpCode', res);
        let jumpUrl = '';
        if (res.data.code == 'S000A000') {
          jumpUrl = res.data.data.templateURL || '';
        } else {
          $Message.error(res.data.data.msg || '服务异常，请稍后重试');
        }

        if (jumpUrl) {
          const url = `${jumpUrl}?pageName=${tpCode}&userCode=${$store.state.LoginUserInfo.userCode}&startUserCode=${$store.state.LoginUserInfo.userCode}&${qs.stringify(params)}&crctoken=${sessionStorage.crctoken}`;
          window.open(url);
        } else {
          window.open(`${origin}/#/blank?pageName=${tpCode}&userCode=${$store.state.LoginUserInfo.userCode}&startUserCode=${$store.state.LoginUserInfo.userCode}&${qs.stringify(params)}&crctoken=${sessionStorage.crctoken}`);
        }
      });
      // if ($config.formPlatformUrls[tpCode] && location.hash.indexOf('old') < 0) {
      //   const url =
      //     window.open(
      //       $config.formPlatformUrls[tpCode] + `?pageName=${tpCode}&userCode=${$store.state.LoginUserInfo.userCode}&startUserCode=${$store.state.LoginUserInfo.userCode}&${qs.stringify(params)}&crctoken=${sessionStorage.crctoken}`
      //     );
      // } else {
      //   window.open(
      //     `${origin}/#/blank?pageName=${tpCode}&userCode=${$store.state.LoginUserInfo.userCode}&startUserCode=${$store.state.LoginUserInfo.userCode}&${qs.stringify(params)}&crctoken=${sessionStorage.crctoken}`
      //   );
      // }
    } else {
      window.open(
        `${origin}/${tpCode}?userCode=${$store.state.LoginUserInfo.userCode}&startUserCode=${$store.state.LoginUserInfo.userCode}${qs.stringify(params)}&source=${obj.source}&crctoken=${sessionStorage.crctoken}`
      );
    }
  };
  if (!fullTpCode) {
    if (categoryCode) {
      $axios.post(`/ems-base-application/category/findCategoryByCode?categoryCode=${categoryCode}`).then((response) => {
        const result = response.data;
        if (!result || !result.tpCode) {
          $app.$Message.warning({
            content: `【${obj.categoryName}】流程没有配置表单请求路径, 无法发起流程`,
            duration: 5
          });
        } else {
          fullTpCode = (result.tpCode == 'payment-plan-gl' || result.tpCode == 'payment-plan') ? 'create-payment-apply' : result.tpCode;
        }
        startProcess();
      })
        .catch((error) => {
          const msg = error.message || '服务异常，请联系管理员';
          $app.$Message.warning(msg);
        });
    }
  } else {
    startProcess();
  }
};

// 关闭从首页打开的全部子页面
util.closeWins = function() {
  if (window.win_Array.length > 0) {
    for (var i = 0; i <= window.win_Array.length; i++) {
      var win_one = window.win_Array[i];
      if (win_one != undefined && !win_one.closed) {
        win_one.close();
      }
    }
  }
};

util.getTaskName = function(actid, taskname) {
  if (actid && actid != 'act_010' && actid != 'ZC_010' && actid != 'act_100' && actid != 'CSIMG_010' && actid != 'ACCOUNTANT_010' && actid != 'GXKJC_010' && actid != 'ERP_010' && actid != 'end') {
    taskname = '业务审批';
  }
  if (actid && actid == 'BDCN_010') {
    taskname = '本地出纳审批';
  }
  if (actid && actid == 'ACTP_010') {
    taskname = '采购申请人';
  }
  return taskname;
};

util.copyPros = function(source, target, excludeNames = [], callback = function() {}) {
  // 强制都是深拷贝
  const tempTarget = extend(true, {}, target);
  if (Object.prototype.toString.call(source) != '[object Object]') {
    console.error('source must be a object!');
    return;
  }
  if (Object.prototype.toString.call(target) != '[object Object]') {
    console.error('target must be a object!');
    return;
  }
  if (excludeNames && Object.prototype.toString.call(excludeNames) != '[object Array]') {
    console.error('excludeNames must be a array!');
    return;
  }
  for (const key of Object.keys(source)) {
    if (!excludeNames || !excludeNames.includes(key)) {
      source[key] = tempTarget[key];
    }
  }
  return source;
};

util.formatToDate = function(shijianchuo, issfm) {
  if (!shijianchuo) {
      return
  } else {
      var time = "";
      if (typeof shijianchuo === 'string') {
          var str = shijianchuo.replace(/-/g, '/').replace(/T|Z/g, ' ').trim();
          if (str.indexOf(".000") > 0) str = str.split(".000")[0];
          time = new Date(str);
      } else {
          time = new Date(shijianchuo);
      }
      var y = time.getFullYear();
      var m = time.getMonth() + 1;
      var d = time.getDate();
      var h = time.getHours();
      var mm = time.getMinutes();
      var s = time.getSeconds();
      if (issfm) {util
          return y + '-' + util.add0(m) + '-' + util.add0(d) + ' ' + util.add0(h) + ':' + util.add0(mm) + ':' + util.add0(s);
      } else {
          return y + '-' + util.add0(m) + '-' + util.add0(d);
      }
  }
}
util.add0 = function(m) {
  return m < 10 ? '0' + m : m
}

export default util;
