export default {
  // 根据值集代码查询
  QueryValueSetByCode: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.get(`/ems-base-application/mams/sys/valueset/item/list/${param.code}`).then((response) => {
        if (response.data.statusCode == '0') {
          let result = [];
          for (let item of response.data.dataResult) {
            result.push({ label: item.vsiValue, value: item.vsiKey });
          }
          resolve(result);
        } else {
          let responseData = { "dataResult": [], "extra": "", "msg": (response.data.msg || "服务异常，请联系管理员"), "statusCode": "-1" };
          resolve(responseData);
        }
      }).catch((error) => {
        let responseData = { "dataResult": [], "extra": "", "msg": (error.response.data.message || "服务异常，请联系管理员"), "statusCode": "-1" };
        resolve(responseData);
      })
    })
  },

  // 根据值集代码、父级值key查询
  QueryValueSetByCodeAndParentKey: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.get(`${process.env.API.baseURL}/sys/valueset/item/list/${param.code}/${param.parentKey}`).then((response) => {
        resolve(response.data);
      });
    });
  },
  // 查询小组
  QueryAllAccountingGroup: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post('/ems-account-service/group/findByNameOrType' + (param ? ('?groupType=' + param.groupType + '&delFlg=' + param.delFlg) : ''), param).then((response) => {
        resolve(response.data);
      }).catch((error) => {
        const responseData = { dataResult: [], extra: '', msg: (error.response.data.message || '服务异常，请联系管理员'), statusCode: '-1' };
        resolve(responseData);
      });
    });
  },

  // 查询组员
  QueryAllAccountingGroupMember: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsAccountingUrl}/group/findCrewsByGroupId` + (param ? ('?groupId=' + param.groupId) : ''), {}).then((response) => {
        resolve(response.data);
      }).catch((error) => {
        const responseData = { dataResult: [], extra: '', msg: (error.response.data.message || '服务异常，请联系管理员'), statusCode: '-1' };
        resolve(responseData);
      });
    });
  },

  // 查询归属公司
  QueryBelongedToCompanys: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`/ems-base-application/mams/mdOu/findAllMdOuList` + (param ? ('/' + param.name) : ''), {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 查询业务大树数据
  QueryBusinessCategorys: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsBaseDataURL}/category/buildCategoryTreeByCondition/`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 查询初始化组织部门信息（三层）
  QueryInitializationOrgs: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.baseURL}/org/findOrgs` + (param ? ('/' + param.name) : ''), {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 根据组织code查询下一级组织部门
  QuerySubOrgsByOrgCode: function({ commit }, param) {
    console.log(param.orgId);
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.baseURL}/org/findSubOrgs/` + param.orgId, {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 根据组织code查询员工
  QueryEmployeeByOrgCode: function({ commit }, param) {
    console.log(param.orgId);
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.baseURL}/org/findSubEmployees/` + param.orgId, {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 根据组织名称查询组织数据
  QueryOrgByOrgName: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.baseURL}/org/findOrg` + (param ? ('/' + param.name) : ''), {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  // 根据员工姓名查询员工
  QueryEmployeeByName: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.claimURL}/org/findEmployee/${param.name}`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  },

  buildCategoryTree: function({ commit }, param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsBaseDataURL}/category/buildCategoryTree`, {}).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          const responseData = { dataResult: [], extra: '', msg: '服务异常，请联系管理员', statusCode: '-1' };
          resolve(responseData);
        });
    });
  }
};
