const path = require('path');
const envConfig = require('./config.js')[process.env.VUE_APP_ENV || 'prd'];

function resolve(dir) {
  return path.join(__dirname, dir);
}

const host = envConfig.host;

module.exports = {
  lintOnSave: false,
  publicPath: '/accounting/',
  productionSourceMap: true,
  pages: {
    index: {
      entry: './src/main.js',
      template: './src/template/index.ejs',
      filename: 'index.html',
      favicon: './favicon.ico',
      title: 'accounting',
      chunks: ['chunk-vendors', 'chunk-common', 'index']
    }
  },
  css: {
    loaderOptions: {
      less: {
        resources: [path.resolve(__dirname, './src')],
        javascriptEnabled: true
      }
    }
  },
  devServer: {
    disableHostCheck: true,
    port: 8080,
    https: false,
    hotOnly: true,
    proxy: {
      '/ems': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/admin': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/ems-base-application': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/ems-account-service': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/ems-payment': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/claim-application': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/bill-service': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/receive-service': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/claim-domain': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/receive-application': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/ems-shared-dispatch-application': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      // 本地打开表单平台
      '/ems/platform': {
        target: host,
        secure: false,
        changeOrigin: true
      },
      '/page/dist': {
        target: host,
        secure: false,
        changeOrigin: true
      }
    }
  },
  chainWebpack: (config) => {
    // 修改文件引入自定义路径
    config.resolve.alias
      .set('@accountingSrc', resolve('./src'))
      .set('@accountingComponents', resolve('./src/components'))
      .set('@accountingViews', resolve('./src/views'))
      .set('@accountingStatic', resolve('./src/static'));

    // 输出文件加hash
    config.output.filename('[name].[hash].js').end();
  },
  transpileDependencies: [
    'iview',
    'ems-components-new'
  ]
};
